package F5::PolicyValidator::AllBlockingOff;

use strict;
use warnings;

use base 'F5::PolicyValidator::Default';

sub validate {
    my ($self, %params) = @_;
    my $dbh = $params{dbh};
    my $logger = $params{logger};
    my $validator = $params{validator};
    my $policy = $params{policy};
    my $policy_id = $policy->{policy_id};

    my ($policy_enforcement_mode) = $dbh->selectrow_array(<<EndQuery, undef, $policy_id);
SELECT flg_disable_rejects
  FROM PLC.PL_POLICIES
 WHERE id = ?
EndQuery

    return unless defined $policy_enforcement_mode;

    return if $policy_enforcement_mode == 1;

    my ($number_of_blocked_violations) = $dbh->selectrow_array(<<EndQuery, undef, $policy_id);
SELECT COUNT(*)
  FROM PLC.PL_BLOCKING
 WHERE policy_id = ?
   AND flg_reject = 1
EndQuery

    my ($number_of_blocking_signature_sets) = $dbh->selectrow_array(<<EndQuery, undef, $policy_id);
SELECT COUNT(*) 
  FROM PLC.PL_POLICY_NEGSIG_SETS
 WHERE policy_id = ?
   AND flg_reject = 1
EndQuery

    if ($number_of_blocked_violations == 0 && $number_of_blocking_signature_sets == 0) {
        $validator->report_error(
            error_type => $F5::PolicyValidator::ERROR_TYPE_LOGIC,
	    error_msg => 'All blocking flags are unset while policy is in blocking enforcement mode.');
    }
}


1;
