package F5::PolicyValidator::MissingBase64Violation;

use strict;
use warnings;

use base 'F5::PolicyValidator::Default';

sub validate {
    my($self, %params) = @_;
    my $dbh = $params{dbh};
    my $logger = $params{logger};
    my $validator = $params{validator};
    my $policy = $params{policy};

    my ($flg_disable_rejects) = $dbh->selectrow_array(<<EndQuery, undef, $policy->{policy_id});
SELECT flg_disable_rejects
  FROM PLC.PL_POLICIES
 WHERE id = ?
EndQuery

    my $flags = $dbh->selectrow_hashref(<<EndQuery, { Slice => {} } , $policy->{policy_id}, F5::Violation::VIOL_PARAMETER_VALUE_BASE64() );
SELECT flg_learn,flg_alarm,flg_reject
  FROM PLC.PL_BLOCKING
 WHERE policy_id = ?
   AND viol_index = ?
EndQuery

    return unless (! $flags->{flg_learn} && ! $flags->{flg_alarm} && ! ($flags->{flg_reject} && ! $flg_disable_rejects));

    my @entity_tables = qw(
                              PLC.PL_PARAM_ATTRIBUTES
                              PLC.PL_ALLOWED_COOKIES
                              PLC.PL_HEADERS
                         );

    for my $entity_table (@entity_tables) {
        my($base64_entity_count) = $dbh->selectrow_array(<<EndQuery, undef, $policy->{policy_id});
SELECT COUNT(*) 
  FROM $entity_table
 WHERE policy_id = ?
   AND flg_is_base64 = 1
EndQuery

        if ($base64_entity_count) {
            $validator->report_error(
                                     error_type => $F5::PolicyValidator::ERROR_TYPE_LOGIC,
                                     error_msg => 'Entities are configured for Base64 decoding while "Illegal Base64 value" violation is disabled');
            last;
        }
    }
}

1;

