package F5::PolicyValidator::ProtocolIndependent;

use strict;
use warnings;

use base 'F5::PolicyValidator::Default';

sub validate {
  my($self, %params) = @_;
  my $dbh = $params{dbh};
  my $logger = $params{logger};
  my $validator = $params{validator};
  my $policy = $params{policy};


  my $is_protocol_free =   $dbh->selectrow_array(<<EndQuery,undef,$policy->{policy_id});
SELECT flg_is_protocol_free
  FROM PLC.PL_POLICIES
 WHERE id = ?
EndQuery

  return if !$is_protocol_free;

  my $urls = $dbh->selectall_hashref(<<EndQuery,'id',undef,$policy->{policy_id});
SELECT id, uri, method_name, count(*)
  FROM PLC.PL_OBJECTS
 WHERE policy_id = ?
 GROUP BY uri, method_name
HAVING count(*) >= 2
EndQuery

  for  my $url ( values %{$urls} ){
       $validator->report_error(error_type => $F5::PolicyValidator::ERROR_TYPE_LOGIC,
                                error_msg => 'The policy contains different protocols for the same path while the policy is protocol independent',
                                table => 'PL_OBJECTS',
                                row_id => $url->{id} );

  }
} 


1;
